"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalLambda = void 0;
const http_1 = require("http");
const DefaultPort = 8000;
class LocalLambda {
    constructor(config) {
        var _a;
        this.handler = config.handler;
        this.port = (_a = config.port) !== null && _a !== void 0 ? _a : DefaultPort;
        this.context = config.context || {};
    }
    run() {
        const server = http_1.createServer((request, response) => {
            let data = '';
            request.on('data', chunk => {
                data += chunk;
            });
            request.on('end', async () => {
                const req = {
                    path: request.url,
                    httpMethod: request.method,
                    method: request.method,
                    headers: request.headers,
                    body: data,
                };
                const rs = await this.handler(req, this.context);
                response.statusCode = rs.statusCode;
                response.writeHead(rs.statusCode, rs.headers);
                response.end(rs.body);
            });
        });
        server.listen(this.port, () => console.info(`🚀  Server ready at http://localhost:${this.port} at '${new Date().toLocaleString()}'`));
    }
}
exports.LocalLambda = LocalLambda;
//# sourceMappingURL=local.lambda.js.map